==> mono_1.1.17.1.orig.tar.gz: mono-1.1.17.1/mcs/class/Microsoft.Build.Engine/Microsoft.Build.BuildEngine/BuildChoose.cs <==
//
// BuildChoose.cs: Represents <Choose>.
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
// 
// (C) 2005 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#if NET_2_0

using System;
using System.Collections.Generic;
using System.Xml;

namespace Microsoft.Build.BuildEngine {
	internal class BuildChoose {
		
		BuildWhen	otherwise;
		Project		project;
		XmlElement	xmlElement;
		List <BuildWhen>	whens;
		
		public BuildChoose (XmlElement xmlElement, Project project)
		{
			this.xmlElement = xmlElement;
			this.project = project;
			this.whens = new List <BuildWhen> ();
		}
		
		public void Evaluate ()
		{
		}
		
		//public bool IsImported {
		//	get { return isImported; }
		//	set { isImported = value; }
		//}
		
		public BuildWhen Otherwise {
			get { return otherwise; }
			set { otherwise = value; }
		}
		
		public List <BuildWhen> Whens {
			get { return whens; }
			set { whens = value; }
		}
	}
}

#endif

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/Microsoft.Build.Engine/Microsoft.Build.BuildEngine/BuildChoose.cs <==
//
// BuildChoose.cs: Represents <Choose>.
//
// Author:
//   Marek Sieradzki (marek.sieradzki@gmail.com)
// 
// (C) 2005 Marek Sieradzki
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#if NET_2_0

using System;
using System.Collections.Generic;
using System.Xml;

namespace Microsoft.Build.BuildEngine {
	internal class BuildChoose {
		
		BuildWhen	otherwise;
		//Project		project;
		//XmlElement	xmlElement;
		List <BuildWhen>	whens;
		
		public BuildChoose (XmlElement xmlElement, Project project)
		{
			//this.xmlElement = xmlElement;
			//this.project = project;
			this.whens = new List <BuildWhen> ();
		}
		
		public void Evaluate ()
		{
		}
		
		//public bool IsImported {
		//	get { return isImported; }
		//	set { isImported = value; }
		//}
		
		public BuildWhen Otherwise {
			get { return otherwise; }
			set { otherwise = value; }
		}
		
		public List <BuildWhen> Whens {
			get { return whens; }
			set { whens = value; }
		}
	}
}

#endif
